@@ -685,3 +685,26 @@ def diff(x, y, x_label='', y_label=''):
             y_label or 'second',
             lineterm='')
     )
+
+
+class RangeComparison:
+    """
+    An object that can be used in comparisons of orderable types to
+    check that a value specified within the given range.
+
+    :param lower_bound: the inclusive lower bound for the acceptable range.
+
+    :param upper_bound: the inclusive upper bound for the acceptable range.
+    """
+    def __init__(self, lower_bound, upper_bound):
+        self.lower_bound = lower_bound
+        self.upper_bound = upper_bound
+
+    def __eq__(self, other):
+        return self.lower_bound <= other <= self.upper_bound
+
+    def __ne__(self, other):
+        return not self == other
+
+    def __repr__(self):
+        return '<Range: [%s, %s]>' % (self.lower_bound, self.upper_bound)
